@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -25,6 +25,7 @@ import org.eclipse.jdt.core.Flags;
 import org.eclipse.jdt.core.IClassFile;
 import org.eclipse.jdt.core.ICodeAssist;
 import org.eclipse.jdt.core.IField;
+import org.eclipse.jdt.core.IInitializer;
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.ILocalVariable;
 import org.eclipse.jdt.core.IMethod;
@@ -39,6 +40,7 @@ import org.eclipse.jdt.core.dom.NodeFinder;
 import org.eclipse.jdt.core.dom.QualifiedName;
 import org.eclipse.jdt.core.dom.StructuralPropertyDescriptor;
 import org.eclipse.jdt.core.dom.ThisExpression;
+import org.eclipse.jdt.core.manipulation.SharedASTProviderCore;
 import org.eclipse.jdt.debug.core.IJavaDebugTarget;
 import org.eclipse.jdt.debug.core.IJavaObject;
 import org.eclipse.jdt.debug.core.IJavaReferenceType;
@@ -51,7 +53,6 @@ import org.eclipse.jdt.internal.debug.core.JDIDebugPlugin;
 import org.eclipse.jdt.internal.debug.core.logicalstructures.JDIPlaceholderVariable;
 import org.eclipse.jdt.internal.debug.eval.ast.engine.ASTEvaluationEngine;
 import org.eclipse.jdt.ui.JavaUI;
-import org.eclipse.jdt.ui.SharedASTProvider;
 import org.eclipse.jdt.ui.text.java.hover.IJavaEditorTextHover;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.text.BadLocationException;
@@ -349,9 +350,9 @@ public class JavaDebugHover implements IJavaEditorTextHover, ITextHoverExtension
 									return null;
 								}
             		    		ITypeRoot typeRoot = (ITypeRoot) codeAssist;
-            		    		ASTNode root= SharedASTProvider.getAST(typeRoot, SharedASTProvider.WAIT_NO, null);
+								ASTNode root = SharedASTProviderCore.getAST(typeRoot, SharedASTProviderCore.WAIT_NO, null);
             		    		if (root == null) {
-	            		    		ASTParser parser = ASTParser.newParser(AST.JLS4);
+									ASTParser parser = ASTParser.newParser(AST.JLS13);
 	            		    		parser.setSource(typeRoot);
 	            		    		parser.setFocalPosition(hoverRegion.getOffset());
 									root = parser.createAST(null);
@@ -386,9 +387,13 @@ public class JavaDebugHover implements IJavaEditorTextHover, ITextHoverExtension
             		if (javaElement instanceof ILocalVariable) {
             		    ILocalVariable var = (ILocalVariable)javaElement;
             		    IJavaElement parent = var.getParent();
-            		    while (!(parent instanceof IMethod) && parent != null) {
+						while (!(parent instanceof IMethod) && !(parent instanceof IInitializer) && parent != null) {
             		    	parent = parent.getParent();
             		    }
+						if (parent instanceof IInitializer && "()V".equals(frame.getSignature()) //$NON-NLS-1$
+								&& "<clinit>".equals(frame.getMethodName())) { //$NON-NLS-1$
+							return findLocalVariable(frame, var.getElementName());
+						}
             		    if (parent instanceof IMethod) {
             				IMethod method = (IMethod) parent;
             				boolean equal = false;
@@ -398,7 +403,7 @@ public class JavaDebugHover implements IJavaEditorTextHover, ITextHoverExtension
             						equal = true;
 								} else {
 									// Check if there are variables captured by lambda, see bug 516278
-									if (LambdaUtils.isLambdaFrame(frame)) {
+									if (org.eclipse.jdt.internal.debug.core.model.LambdaUtils.isLambdaFrame(frame)) {
 										return LambdaUtils.findLocalVariableFromLambdaScope(frame, var);
 									}
             					}
@@ -430,7 +435,7 @@ public class JavaDebugHover implements IJavaEditorTextHover, ITextHoverExtension
 										}
 									} else {
 										// Check if there are variables captured by lambda, see bug 516278
-										if (LambdaUtils.isLambdaFrame(frame)) {
+										if (org.eclipse.jdt.internal.debug.core.model.LambdaUtils.isLambdaFrame(frame)) {
 											return LambdaUtils.findLocalVariableFromLambdaScope(frame, var);
 										}
 									}
